# Python Client Library for Foxglove Data Platform

This library provides a convenient python client for [Foxglove's Data Platform](https://foxglove.dev/data-platform).

In order to use the client you will first have to create an API token for your organization on your organization's [settings page](https://console.foxglove.dev/organization).

## Sample Usage

Examples of various client features can be found in the `examples` directory.

## Running Tests

```bash
pipenv install --dev
pipenv run python -m pytest
```

## Stay in touch

Join our [Slack channel](https://foxglove.dev/join-slack) to ask questions, share feedback, and stay up to date on what our team is working on.
